@@ -106,7 +106,7 @@ class SurveyQuestion(models.Model):
     kind = models.IntegerField(choices=FIELD_TYPE_CHOICES)
     help_text = models.TextField(blank=True)
     ordinal = models.IntegerField(blank=True)
-    required = models.BooleanField()
+    required = models.BooleanField(default=False)
     trello_list_id = models.CharField(max_length=100, blank=True)
 
     class Meta:
@@ -134,7 +134,8 @@ class SurveyQuestion(models.Model):
             kwargs.update({"widget": forms.RadioSelect(), "queryset": self.choices.all()})
         elif self.kind == SurveyQuestion.CHECKBOX_FIELD:
             field_class = forms.ModelMultipleChoiceField
-            kwargs.update({"widget": forms.CheckboxSelectMultiple(), "queryset": self.choices.all()})
+            kwargs.update({"widget": forms.CheckboxSelectMultiple(),
+                           "queryset": self.choices.all()})
         elif self.kind == SurveyQuestion.BOOLEAN_FIELD:
             field_class = forms.BooleanField
 
